[Cdd-commits] r1193 - in cdd/trunk/webtools: . po templates webconf

CDD Subversion Commit noreply at alioth.debian.org
Sun Nov 2 08:00:54 UTC 2008


Author: tille
Date: Sun Nov  2 08:00:53 2008
New Revision: 1193

Added:
   cdd/trunk/webtools/blendstasktools.py
      - copied, changed from r1185, cdd/trunk/webtools/distasktools.py
   cdd/trunk/webtools/po/blends-webtools.pot
      - copied, changed from r1185, cdd/trunk/webtools/po/dis-webtools.pot
Removed:
   cdd/trunk/webtools/distasktools.py
   cdd/trunk/webtools/po/dis-webtools.pot
Modified:
   cdd/trunk/webtools/bugs.py
   cdd/trunk/webtools/ddpo_register.py
   cdd/trunk/webtools/mkmo.sh
   cdd/trunk/webtools/mkpo.sh
   cdd/trunk/webtools/mkpot.sh
   cdd/trunk/webtools/po/da.po
   cdd/trunk/webtools/po/de.po
   cdd/trunk/webtools/tasks.py
   cdd/trunk/webtools/templates/bugs.xhtml
   cdd/trunk/webtools/webconf/debian-edu.conf
   cdd/trunk/webtools/webconf/debian-gis.conf
   cdd/trunk/webtools/webconf/debian-junior.conf
   cdd/trunk/webtools/webconf/debian-med.conf
   cdd/trunk/webtools/webconf/debian-science.conf
   cdd/trunk/webtools/webconf/debichem.conf
Log:
Rename dis to blends


Copied: cdd/trunk/webtools/blendstasktools.py (from r1185, cdd/trunk/webtools/distasktools.py)
==============================================================================
--- cdd/trunk/webtools/bugs.py	(original)
+++ cdd/trunk/webtools/bugs.py	Sun Nov  2 08:00:53 2008
@@ -12,7 +12,7 @@
 from genshi.template import TemplateLoader
 from genshi import Markup
 
-from distasktools import DisDependencies, ReadConfig, DEPENDENT, SUGGESTED, DONE, BUGLISTCAT
+from blendstasktools import BlendDependencies, ReadConfig, DEPENDENT, SUGGESTED, DONE, BUGLISTCAT
 
 if len(argv) <= 1:
 	print >>stderr, "Usage: %s <Blend name>\n       The <Blend name> needs a matching config file webconf/<Blend name>.conf"\
@@ -154,17 +154,17 @@
 template_dir = os.path.join(current_dir, 'templates')
 
 # Initialize i18n
-domain = 'dis-webtools'
+domain = 'blends-webtools'
 gettext.install(domain)
 
 # initialize gensi
 loader = TemplateLoader([template_dir], auto_reload=True)
 
-cdeps=DisDependencies(argv[1])
+cdeps=BlendDependencies(argv[1])
 if cdeps.data['pkglist'] == '':
 	print >>stderr, "Config file webconf/%s.conf is lacking pkglist field." % (argv[1])
 	exit(-1)
-cdeps.GetAllDependencies(source=0) # Set source=1 in case source pakcages shoudl be displayed
+cdeps.GetAllDependencies(source=0) # Set source=1 in case source packages should be displayed
 packages = cdeps.GetNamesAndSourceDict(dependencytypes=('depends','recommends','suggests'))
 
 outputdir = cdeps.CheckOrCreateOutputDir('bugs')
@@ -173,12 +173,20 @@
 
 t = datetime.now()
 data = cdeps.data
-data['tasks']           = cdeps.GetTaskDescDict()
-data['taskskeys']       = cdeps.metapackagekeys
-data['lang']            = 'en'
-data['othertasks']      = _("Links to other tasks")
-data['taskslink']       = _("Tasks")
-data['updatetimestamp'] = _('Last update:') + ' ' + formatdate(time.mktime(t.timetuple()))
+data['tasks']             = cdeps.GetTaskDescDict()
+data['taskskeys']         = cdeps.metapackagekeys
+data['lang']              = 'en'
+data['othertasks']        = _("Links to other tasks")
+data['taskslink']         = _("Tasks")
+data['legend']            = _("Legend")
+data['updatetimestamp']   = _('Last update:') + ' ' + formatdate(time.mktime(t.timetuple()))
+data['weightexplanation'] = _("""To estimate the overall status of the packages in the dependencies of
+a metapackage a weighted severity is calculated.  Done bugs are ignored and bugs in dependent and
+recommendet packages are weighted by factor three compared to suggested packages.  Release critical
+bugs have a much larger weight than important, while the contribution of normal bugs is even smaller
+and minor bugs have a very small weight.  Wishlist bugs are ignored in this calculation.  The resulting
+sum is compared to some boundaries to find a verbal form.  The actual numbers need some adjustment
+ta make real sense - this evaluation method is in testing phase.""")
 if data['advertising'] != None:
 	# If data['advertising'] is enclosed in _() gettext tries to ask for translations of 'advertising'
 	# which makes no sense.  That's why this is masked by an extra string variable
@@ -250,28 +258,34 @@
 	elif wsev < GOOD:
 		weightedsev[task] = _('Metapackage is in good shape')
 	elif wsev < SATISFACTORY:
-		weightedsev[task] = _('Cosider looking into bugs of this metapackage')
+		weightedsev[task] = _('Consider looking into bugs of this metapackage')
 	elif wsev < PASS:
 		weightedsev[task] = _('Looking into bugs of this metapackage is recommended')
 	else:
 		weightedsev[task] = _('Immediately looking into bugs of the dependencies of this metapackage is advised')
 	weightedsev[task] += ' (%i)' % wsev
 
-data['headings'] = {DEPENDENT : 'Open bugs in dependent packages',
-                    SUGGESTED : 'Open bugs in suggested packages',
-                    DONE      : 'Done bugs'
+data['headings'] = {DEPENDENT : _('Open bugs in dependent packages'),
+                    SUGGESTED : _('Open bugs in suggested packages'),
+                    DONE      : _('Done bugs')
+                   }
+data['nobugs']   = {DEPENDENT : _('No open bugs in dependent packages'),
+                    SUGGESTED : _('No open bugs in suggested packages'),
+                    DONE      : _('No done bugs')
                    }
 data['cssclass'] = {DEPENDENT : 'bugsdependent',
                     SUGGESTED : 'bugssuggested',
                     DONE      : 'bugsdone'
                    }
 
+data['task']            = task
+data['nbugs']           = nbugs
+data['ndone']           = ndone
+data['buglistcat']      = BUGLISTCAT
+data['severities']      = SEVERITIES
+
 for task in packages.keys():
-	data['task']            = task
-	data['nbugs']           = nbugs
-	data['ndone']           = ndone
 	data['buglist']         = buglist[task]
-	data['buglistcat']      = BUGLISTCAT
 	data['severitysummary'] = severitysummary[task]
 	data['weightedsev']     = weightedsev[task]
 

Modified: cdd/trunk/webtools/ddpo_register.py
==============================================================================
--- cdd/trunk/webtools/ddpo_register.py	(original)
+++ cdd/trunk/webtools/ddpo_register.py	Sun Nov  2 08:00:53 2008
@@ -5,14 +5,14 @@
 
 from sys import argv, exit, stderr
 
-from distasktools import DisDependencies, ReadConfig
+from blendstasktools import BlendDependencies, ReadConfig
 
 if len(argv) <= 1:
 	print >>stderr, "Usage: %s <Blend name>\n       The <Blend name> needs a matching config file webconf/<Blend name>.conf"\
                         % argv[0]
 	exit(-1)
 
-cdeps=DisDependencies(argv[1])
+cdeps=BlendDependencies(argv[1])
 if cdeps.data['pkglist'] == '':
 	print >>stderr, "Config file webconf/%s.conf is lacking pkglist field." % (argv[1])
 	exit(-1)

Modified: cdd/trunk/webtools/mkmo.sh
==============================================================================
--- cdd/trunk/webtools/mkmo.sh	(original)
+++ cdd/trunk/webtools/mkmo.sh	Sun Nov  2 08:00:53 2008
@@ -1,6 +1,6 @@
 #!/bin/sh -e
 
-domain="dis-webtools"
+domain="blends-webtools"
 podir="po"
 [ "--force" != "$1" ] || rm -rf "locale"
 ls -1 "$podir"/*.po | xargs -I{} basename '{}' .po | while read lang; do

Modified: cdd/trunk/webtools/mkpo.sh
==============================================================================
--- cdd/trunk/webtools/mkpo.sh	(original)
+++ cdd/trunk/webtools/mkpo.sh	Sun Nov  2 08:00:53 2008
@@ -1,5 +1,5 @@
 #!/bin/sh -e
-NAME=dis-webtools
+NAME=blends-webtools
 TMPPOT=tmp.pot
 
 cd po

Modified: cdd/trunk/webtools/mkpot.sh
==============================================================================
--- cdd/trunk/webtools/mkpot.sh	(original)
+++ cdd/trunk/webtools/mkpot.sh	Sun Nov  2 08:00:53 2008
@@ -1,5 +1,5 @@
 #!/bin/sh
-NAME=dis-webtools
+NAME=blends-webtools
 
 xgettext \
 	--default-domain="$NAME" \

Copied: cdd/trunk/webtools/po/blends-webtools.pot (from r1185, cdd/trunk/webtools/po/dis-webtools.pot)
==============================================================================
--- cdd/trunk/webtools/po/dis-webtools.pot	(original)
+++ cdd/trunk/webtools/po/blends-webtools.pot	Sun Nov  2 08:00:53 2008
@@ -6,9 +6,9 @@
 #, fuzzy
 msgid ""
 msgstr ""
-"Project-Id-Version: dis-webtools 0.1.1\n"
+"Project-Id-Version: blends-webtools 0.1.1\n"
 "Report-Msgid-Bugs-To: debian-custom at lists.debian.org\n"
-"POT-Creation-Date: 2008-10-29 20:29+0100\n"
+"POT-Creation-Date: 2008-11-02 00:30+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"

Modified: cdd/trunk/webtools/po/da.po
==============================================================================
--- cdd/trunk/webtools/po/da.po	(original)
+++ cdd/trunk/webtools/po/da.po	Sun Nov  2 08:00:53 2008
@@ -5,7 +5,7 @@
 #
 #, fuzzy
 msgid   ""
-msgstr  "Project-Id-Version: dis-webtools 0.1.1\n"
+msgstr  "Project-Id-Version: blends-webtools 0.1.1\n"
         "Report-Msgid-Bugs-To: debian-custom at lists.debian.org\n"
         "POT-Creation-Date: 2008-10-29 20:29+0100\n"
         "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"

Modified: cdd/trunk/webtools/po/de.po
==============================================================================
--- cdd/trunk/webtools/po/de.po	(original)
+++ cdd/trunk/webtools/po/de.po	Sun Nov  2 08:00:53 2008
@@ -7,7 +7,7 @@
 msgid   ""
 msgstr  "Project-Id-Version: 0.1\n"
         "Report-Msgid-Bugs-To: debian-custom at lists.debian.org\n"
-        "POT-Creation-Date: 2008-10-29 20:29+0100\n"
+        "POT-Creation-Date: 2008-11-02 00:28+0100\n"
         "PO-Revision-Date: 2008-02-17 17:13:51+0200\n"
         "Last-Translator: Steffen Möller, Andreas Tille <{moeller,tille}@debian.org>\n"
         "Language-Team: German <de at li.org>\n"
@@ -85,6 +85,7 @@
         "Beschreibung des Projekts an die <a href=\"mailto:%s\">%s Mailingliste</a> zu schicken."
 
 #: tasks.py:100
+#, python-format
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
@@ -92,8 +93,8 @@
 msgstr  "Die Liste auf der rechten Seite enthält verschiedene Softwareprojekte, die für das %s "
         "Projekt von Interesse sind. Derzeit sind nur einige von diesen als Debianpakete "
         "verfügbar. Zielsetzung ist es jedoch, all die Software für %s zu paketieren, um einen "
-        "qualitativ hochwertiges Debian Pure Blend (interne Anpassung von Debian an "
-        "spezielle Bedürfnisse) zu erstellen."
+        "qualitativ hochwertiges Debian Pure Blend (interne Anpassung von Debian an spezielle "
+        "Bedürfnisse) zu erstellen."
 
 #: tasks.py:101
 msgid   "Tasks page"
@@ -192,14 +193,14 @@
 msgstr  "Pakete"
 
 #: tasks.py:142
+#, python-format
 msgid   "A %sDebian Pure Blend%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
-msgstr  "Ein %sDebian Pure Blend%s ist ein internes "
-        "Debianprojekt, das einen Satz von Paketen zusammenstellt, der Nutzern hilft, bestimmte "
-        "Aufgaben Ihrer Arbeit zu bewältigen.  Die Liste rechts zeigt Aufgaben, die durch %s "
-        "zusammengestellt wurden."
+msgstr  "Ein %sDebian Pure Blend%s ist ein internes Debianprojekt, das einen Satz von Paketen "
+        "zusammenstellt, der Nutzern hilft, bestimmte Aufgaben Ihrer Arbeit zu bewältigen.  Die "
+        "Liste rechts zeigt Aufgaben, die durch %s zusammengestellt wurden."
 
 #: tasks.py:200
 msgid   "Links to other tasks"

Modified: cdd/trunk/webtools/tasks.py
==============================================================================
--- cdd/trunk/webtools/tasks.py	(original)
+++ cdd/trunk/webtools/tasks.py	Sun Nov  2 08:00:53 2008
@@ -15,7 +15,7 @@
 from genshi.template import TemplateLoader
 from genshi import Markup
 
-from distasktools import DisDependencies, ReadConfig
+from blendstasktools import BlendDependencies, ReadConfig
 
 languages = ('en', 'cs', 'da', 'de', 'es', 'fi', 'fr', 'it', 'ja', 'ko', 'nl', 'pl', 'pt_BR', 'ru', 'zh_CN')
 
@@ -24,11 +24,11 @@
                         % argv[0]
 	exit(-1)
 
-cdeps=DisDependencies(argv[1])
+cdeps=BlendDependencies(argv[1])
 cdeps.GetAllDependencies()
 packages     = cdeps.GetNamesOnlyDict()
 cdeps.GetTranslations(languages)
-cdeps.MarkupPreformatedStringsDIS()
+cdeps.MarkupPreformatedStringsBlend()
 
 data = cdeps.data
 data['tasks']            = cdeps.GetTaskDescDict()
@@ -49,7 +49,7 @@
 template_dir = os.path.join(current_dir, 'templates')
 
 # Initialize i18n
-domain = 'dis-webtools'
+domain = 'blends-webtools'
 gettext.install(domain)
 l10nstring = {}
 for lang in languages:
@@ -142,7 +142,7 @@
 	data['idxsummary']        = _("""A %sDebian Pure Blend%s is a Debian internal project which assembles
 a set of packages that might help users to solve certain tasks of their work.  The list on
 the right shows the tasks of %s.""" ) \
-                                      % ('<a href="http://dis.alioth.debian.org/dis/">', '</a>', data['projectname'])
+                                      % ('<a href="http://cdd.alioth.debian.org/blends/">', '</a>', data['projectname'])
 	data['idxsummary']        = Markup(data['idxsummary'])
 
 	# Create the index page

Modified: cdd/trunk/webtools/templates/bugs.xhtml
==============================================================================
--- cdd/trunk/webtools/templates/bugs.xhtml	(original)
+++ cdd/trunk/webtools/templates/bugs.xhtml	Sun Nov  2 08:00:53 2008
@@ -57,13 +57,23 @@
                           </py:for>
                         </div>
 		</div>
+
+		<span class="section">${legend}</span>
+		<div class="section">
+			<div class="sectionTop"/>
+			<div class="row">
+                          <py:for each="s in severities">
+                              <div class="severity ${s}">${s}</div>
+                          </py:for>
+                        </div>
+		</div>
 	</td>
 	<td class="main">
 		<div class="pageBody">
 
 <h1>Summary bugs page of ${tasks[task].metapkg.PrintedName.capitalize()} meta package</h1>
 
-<div class="severitysummary">${weightedsev}</div>
+<div class="severitysummary">${weightedsev}<sup>*</sup></div>
 
 <span py:choose="">
   <span py:when="nbugs[task]+ndone[task] != 0">
@@ -92,8 +102,7 @@
 	    </py:for>
 	  </table>
 	</span>
-	<span py:otherwise="">No bugs in category ${cat}
-	</span>
+	<span py:otherwise=""><h2>${nobugs[cat]}</h2></span>
       </span>
     </py:for>
    </span>
@@ -101,6 +110,9 @@
   ${tasks[task].metapkg.PrintedName.capitalize()} has no known nbugs =
   ${nbugs[task]}  ndone = ${ndone[task]}</h2></span>
 </span>
+<div id="footer">
+  ${weightexplanation}
+</div>
 		</div>
 	</td>
 </tr>

Modified: cdd/trunk/webtools/webconf/debian-edu.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-edu.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-edu.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debian-edu
+Blend:       debian-edu
 ProjectName: Debian Edu
 ProjectUrl:  http://debian-edu.alioth.debian.org/
 Homepage:    http://wiki.debian.org/DebianEdu

Modified: cdd/trunk/webtools/webconf/debian-gis.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-gis.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-gis.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debian-gis
+Blend:       debian-gis
 ProjectName: Debian GIS
 ProjectUrl:  http://pkg-grass.alioth.debian.org/
 Homepage:    http://wiki.debian.org/DebianGis

Modified: cdd/trunk/webtools/webconf/debian-junior.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-junior.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-junior.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debian-junior
+Blend:       debian-junior
 ProjectName: Debian Junior
 ProjectUrl:  http://cdd.alioth.debian.org/projects/debian-jr
 Homepage:    http://www.debian.org/devel/debian-jr

Modified: cdd/trunk/webtools/webconf/debian-med.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-med.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-med.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debian-med
+Blend:       debian-med
 ProjectName: Debian Med
 ProjectUrl:  http://debian-med.alioth.debian.org/
 Homepage:    http://www.debian.org/devel/debian-med

Modified: cdd/trunk/webtools/webconf/debian-science.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-science.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-science.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debian-science
+Blend:       debian-science
 ProjectName: Debian Science
 ProjectUrl:  http://wiki.debian.org/DebianScience
 Homepage:    http://wiki.debian.org/DebianScience

Modified: cdd/trunk/webtools/webconf/debichem.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debichem.conf	(original)
+++ cdd/trunk/webtools/webconf/debichem.conf	Sun Nov  2 08:00:53 2008
@@ -1,4 +1,4 @@
-DIS:         debichem
+Blend:       debichem
 ProjectName: DebiChem
 ProjectUrl:  http://alioth.debian.org/projects/debichem
 Homepage:    http://alioth.debian.org/projects/debichem



More information about the Cdd-commits mailing list
--- cdd/trunk/webtools/distasktools.py	(original)
+++ cdd/trunk/webtools/blendstasktools.py	Sun Nov  2 08:00:53 2008
@@ -2,7 +2,7 @@
 # Copyright 2008: Andreas Tille <tille at debian.org>
 # License: GPL
 
 # DIS Metapackages are listing a set of Dependencies
 # These might be fullfilled by the Debian package
 # set or not.
 #
@@ -52,18 +52,18 @@
 DONE       = 2
 BUGLISTCAT = (DEPENDENT, SUGGESTED, DONE )
 
-def ReadConfig(disname=''):
-    # Try to read config file CONFDIR/<disname>.conf
-    conffile = CONFDIR + '/' + disname + '.conf'
+def ReadConfig(blendname=''):
+    # Try to read config file CONFDIR/<blendname>.conf
+    conffile = CONFDIR + '/' + blendname + '.conf'
     if not os.access(conffile, os.R_OK):
-        # if config file can not be found in local dir, try /etc/dis/webconf as fallback
-        conffile_default = '/etc/dis/webconf/' + disname + '.conf'
+        # if config file can not be found in local dir, try /etc/blends/webconf as fallback
+        conffile_default = '/etc/blends/webconf/' + blendname + '.conf'
         if not os.access(conffile_default, os.R_OK):
             print >>stderr, "Unable to open config file %s or %s." % (conffile, conffile_default)
             exit(-1)
         conffile = conffile_default
     f = open(conffile, 'r')
-    ret = { 'DIS'         : '',
+    ret = { 'Blend'       : '',
             'projectname' : '',
             'projecturl'  : '',
             'homepage'    : '',
@@ -78,7 +78,7 @@
             'advertising' : None,  # headline with advertising string is optional
           }
     for stanza in deb822.Sources.iter_paragraphs(f, shared_storage=False):    
-        ret['DIS']         = stanza['dis']          # short name of the project
+        ret['Blend']       = stanza['blend']        # short name of the project
         ret['projectname'] = stanza['projectname']  # Printed name of the project
         ret['projecturl']  = stanza['projecturl']   # Link to the developer page with dynamic content
                                                     # like for instance these tasks pages
@@ -94,8 +94,8 @@
         ret['outputdir']   = stanza['outputdir']    # Dir for storing output HTML files
         ret['datadir']     = stanza['datadir']      # Dir for storing SVN information about project
         ret['cachedir']    = stanza['cachedir']     # Cache for Package and DDTP files - could be common
-                                                    # for all DISs that's why the default value makes sense
-        ret['vcsdir']      = stanza['vcsdir']       # Path to DIS information files at svn.debian.org
+                                                    # for all Blends that's why the default value makes sense
+        ret['vcsdir']      = stanza['vcsdir']       # Path to Blend information files at svn.debian.org
         if stanza.has_key('advertising'):
             # we have to remove the gettext _() call which was inserted into the config
             # file to enable easy input for config file editors - but the call has to
@@ -108,9 +108,9 @@
 
 
 def InitTasksFiles(data):
     # Obtain tasks files from SVN of a DIS
     # The specification of the repository containing the tasks files
     # of a DIS can be done in webconf/<DIS>.conf
 
     # tasks directory to obtain dependencies and debian/control to obtain meta
     # information like the metapackage prefix
@@ -176,9 +176,9 @@
 class DependantPackage:
     # Hold information about a program that is in dependency list
 
-    def __init__(self, disname=None, taskname=None):
-        self.disname        = disname  # DIS that includes the package in dependency list
-        self.taskname       = taskname # Task which includes the Dependency
+    def __init__(self, blendname=None, taskname=None):
+        self.blendname      = blendname # Blend that includes the package in dependency list
+        self.taskname       = taskname  # Task which includes the Dependency
         self.pkg            = None # Name of dependant package
         self.PrintedName    = None # Only for Meta package names - no use for a real dependant package
                                    # FIXME -> object model
@@ -213,31 +213,31 @@
         # Sort according to package name
         return cmp(self.pkg, other.pkg)
 
-class DisDependencies:
-    # Provide a list of depencencies defined in Metapackages
-    # This class concerns _all_ tasks of a DIS and is the most
+class BlendDependencies:
+    # Provide a list of depencencies defined in metapackages
+    # This class concerns _all_ tasks of a Blend and is the most
     # complete source of information.  If only a single task
-    # should be handled by a tool that uses distasktools
+    # should be handled by a tool that uses blendtasktools
     # probably the class TaskDependencies (see below) is
     # your friend
 
-    def __init__(self, disname):
+    def __init__(self, blendname):
 
         # This Instance of the Available class contains all
         # information about packages that are avialable in Debian
         # See below for more information about Available class
         global available
 
-        self.data            = ReadConfig(disname)
-        self.disname         = self.data['DIS']
+        self.data            = ReadConfig(blendname)
+        self.blendname       = self.data['Blend']
         self.tasksdir        = InitTasksFiles(self.data)
         self.tasks           = {} # Dictionary of TasksDependency objects
         self.metapackagekeys = []
         self.available       = available
         self.alldeps_in_main = [] # sorted string list of package names with all packages
                                   # relevant for a DIS that are in main Debian (for use in DDTP)
         self.alldeps_in_main_info = {} # complete dictionary with package information
                                   # with all packages relevant for a DIS that are in
                                   # main to easily feed DDTP translation into the structures
                                   # -->
                                   # self.alldeps_in_main = self.alldeps_in_main_info.keys().sort()
@@ -256,13 +256,13 @@
         if self.metapackagekeys == []:
             self._GetMetapackages()
 
         # Obtain the prefix of the meta packages of the DIS using dis-dev tools dis_get_names
         if os.access('/usr/share/dis-dev/dis-get-names', os.X_OK):
             dis_get_names = '/usr/share/dis-dev/dis-get-names'
         elif os.access(os.getcwd() + '/dis-get-names', os.X_OK):
             dis_get_names = os.getcwd() + '/dis-get-names'
         else:
-            print >>stderr, "Please either install package dis-dev or install a copy of devtools/dis-get-names in your working directory"
+            print >>stderr, "Please either install package Blends-dev or install a copy of devtools/blends-get-names in your working directory"
             exit(-1)
 
         # The prefix is used to build the meta package name that belongs to the task
@@ -271,7 +271,7 @@
         prefix = pipe.read().strip() + '-'
         pipe.close()
         for task in self.metapackagekeys:
-            td = TaskDependencies(self.disname, task=task, tasksdir=self.tasksdir, prefix=prefix)
+            td = TaskDependencies(self.blendname, task=task, tasksdir=self.tasksdir, prefix=prefix)
             td.GetTaskDependencies(source)
             self.tasks[task] = td
 
@@ -351,10 +351,10 @@
         return ret
 
     def GetTaskDescDict(self):
         # Return dictionary with description information of all tasks of a DIS
         return self.tasks
 
-    def GetAllDependantPackagesOfDIS(self, dependencytypes=()):
+    def GetAllDependentPackagesOfBlend(self, dependencytypes=()):
         # David Paleino needs for his DDTP web tool a list of
         # all available Dependencies.
         # Here only those packages are returned that are in
@@ -389,7 +389,7 @@
         return self.alldeps_in_main
 
     def GetTranslations(self, languages=()):
         # Get DDTP translations for the package dependencies in a DIS
 
         if languages == ():
             return
@@ -409,7 +409,7 @@
         # Only main has DDTP translations
         component = 'main'
 
-        pks2translate = self.GetAllDependantPackagesOfDIS()
+        pks2translate = self.GetAllDependentPackagesOfBlend()
         for lang in languages:
             if lang == 'en':
                 continue
@@ -442,9 +442,9 @@
                        (errtxt, ddtpfile, lang)
                 os.unlink(file)
 
-    def MarkupPreformatedStringsDIS(self):
+    def MarkupPreformatedStringsBlend(self):
         # Genshi does not touch strings that are marked with "Markup()" - so just
         # mark the strings that are ready formatted for the whole DIS
         for task in self.metapackagekeys:
             tdeps = self.tasks[task]
             tdeps.MarkupPreformatedStrings()
@@ -465,11 +465,11 @@
 
 
 class TaskDependencies:
-    # List of depencencies defined in one Metapackage
-    def __init__(self, disname, task, tasksdir=None, prefix=''):
+    # List of depencencies defined in one metapackage
+    def __init__(self, blendname, task, tasksdir=None, prefix=''):
 
-        self.data     = ReadConfig(disname)
-        self.disname  = self.data['DIS']
+        self.data     = ReadConfig(blendname)
+        self.blendname  = self.data['Blend']
         if tasksdir != None:
             self.tasksdir = tasksdir
         else:
@@ -493,10 +493,10 @@
         self.available = available
 
         # Main information for a task
-        self.metapkg             = DependantPackage(self.disname, self.task)
+        self.metapkg             = DependantPackage(self.blendname, self.task)
         self.metapkg.pkg         = prefix + task
 
         # If a DIS just bases on the meta package of an other DIS (this is the
         # case in Debian Science which bases on med-bio for biology and gis-workstation
         # for geography it makes no sense to build an own sentinel page but read
         # meta package information of other meta packages and include the content
@@ -576,7 +576,7 @@
 
                 if key in dep_strength_keys:
                     # Hack: Debian Edu tasks files are using '\' at EOL which is broken
                     #       in RFC 822 files, but dis-gen-control from dis-dev 0.5.x relies
                     #       on this.  So remove this stuff here for the Moment
                     dependencies = re.sub('\\\\\n\s+', '', stanza[key])
 
@@ -598,7 +598,7 @@
                         # just put the current one into the right list of dependencies
                         # before initiating the next instance
                         self._AppendDependency2List(dep, source)
-                        dep = DependantPackage(self.disname, self.task)
+                        dep = DependantPackage(self.blendname, self.task)
                         # Store the comments in case they might be usefull for later applications
                         dep.why            = why
                         dep.responsible    = responsible
@@ -2,7 +2,7 @@
 # License: GPL
 
-# DIS Metapackages are listing a set of Dependencies
+# Blends metapackages are listing a set of Dependencies
 # These might be fullfilled by the Debian package
 # set or not.
@@ -108,9 +108,9 @@
 
 def InitTasksFiles(data):
-    # Obtain tasks files from SVN of a DIS
+    # Obtain tasks files from SVN of a Blend
     # The specification of the repository containing the tasks files
@@ -108,9 +108,9 @@
     # The specification of the repository containing the tasks files
-    # of a DIS can be done in webconf/<DIS>.conf
+    # of a Blend can be done in webconf/<Blend>.conf
 
     # tasks directory to obtain dependencies and debian/control to obtain meta
@@ -213,31 +213,31 @@
         self.available       = available
         self.alldeps_in_main = [] # sorted string list of package names with all packages
-                                  # relevant for a DIS that are in main Debian (for use in DDTP)
+                                  # relevant for a Blend that are in main Debian (for use in DDTP)
         self.alldeps_in_main_info = {} # complete dictionary with package information
@@ -213,31 +213,31 @@
         self.alldeps_in_main_info = {} # complete dictionary with package information
-                                  # with all packages relevant for a DIS that are in
+                                  # with all packages relevant for a Blend that are in
                                   # main to easily feed DDTP translation into the structures
                                   # -->
@@ -256,13 +256,13 @@
             self._GetMetapackages()
 
-        # Obtain the prefix of the meta packages of the DIS using dis-dev tools dis_get_names
+        # Obtain the prefix of the meta packages of the Blend using blends-dev tools dis_get_names
         if os.access('/usr/share/dis-dev/dis-get-names', os.X_OK):
             dis_get_names = '/usr/share/dis-dev/dis-get-names'
@@ -351,10 +351,10 @@
 
     def GetTaskDescDict(self):
-        # Return dictionary with description information of all tasks of a DIS
+        # Return dictionary with description information of all tasks of a Blend
         return self.tasks
 
@@ -389,7 +389,7 @@
 
     def GetTranslations(self, languages=()):
-        # Get DDTP translations for the package dependencies in a DIS
+        # Get DDTP translations for the package dependencies in a Blend
 
         if languages == ():
@@ -442,9 +442,9 @@
         # Genshi does not touch strings that are marked with "Markup()" - so just
-        # mark the strings that are ready formatted for the whole DIS
+        # mark the strings that are ready formatted for the whole Blend
         for task in self.metapackagekeys:
             tdeps = self.tasks[task]
@@ -493,10 +493,10 @@
         self.metapkg.pkg         = prefix + task
 
-        # If a DIS just bases on the meta package of an other DIS (this is the
+        # If a Blend just bases on the meta package of an other Blend (this is the
         # case in Debian Science which bases on med-bio for biology and gis-workstation
         # for geography it makes no sense to build an own sentinel page but read
@@ -576,7 +576,7 @@
                 if key in dep_strength_keys:
                     # Hack: Debian Edu tasks files are using '\' at EOL which is broken
-                    #       in RFC 822 files, but dis-gen-control from dis-dev 0.5.x relies
+                    #       in RFC 822 files, but blend-gen-control from blends-dev 0.5.x relies
                     #       on this.  So remove this stuff here for the Moment
                     dependencies = re.sub('\\\\\n\s+', '', stanza[key])

Modified: cdd/trunk/webtools/bugs.py
==============================================================================